@@ -1,7 +1,5 @@
 use {super::*, CompileErrorKind::*};
 
-const VALID_ALIAS_ATTRIBUTES: [Attribute; 1] = [Attribute::Private];
-
 #[derive(Default)]
 pub(crate) struct Analyzer<'src> {
   assignments: Table<'src, Assignment<'src>>,
@@ -10,35 +8,58 @@ pub(crate) struct Analyzer<'src> {
 }
 
 impl<'src> Analyzer<'src> {
-  pub(crate) fn analyze(ast: &Ast<'src>) -> CompileResult<'src, Justfile<'src>> {
-    Analyzer::default().justfile(ast)
+  pub(crate) fn analyze(
+    loaded: Vec<PathBuf>,
+    paths: &HashMap<PathBuf, PathBuf>,
+    asts: &HashMap<PathBuf, Ast<'src>>,
+    root: &Path,
+  ) -> CompileResult<'src, Justfile<'src>> {
+    Analyzer::default().justfile(loaded, paths, asts, root)
   }
 
-  fn justfile(mut self, ast: &Ast<'src>) -> CompileResult<'src, Justfile<'src>> {
+  fn justfile(
+    mut self,
+    loaded: Vec<PathBuf>,
+    paths: &HashMap<PathBuf, PathBuf>,
+    asts: &HashMap<PathBuf, Ast<'src>>,
+    root: &Path,
+  ) -> CompileResult<'src, Justfile<'src>> {
     let mut recipes = Vec::new();
 
-    for item in &ast.items {
-      match item {
-        Item::Alias(alias) => {
-          self.analyze_alias(alias)?;
-          self.aliases.insert(alias.clone());
-        }
-        Item::Assignment(assignment) => {
-          self.analyze_assignment(assignment)?;
-          self.assignments.insert(assignment.clone());
-        }
-        Item::Comment(_) => (),
-        Item::Recipe(recipe) => {
-          if recipe.enabled() {
-            Self::analyze_recipe(recipe)?;
-            recipes.push(recipe);
+    let mut stack = Vec::new();
+    stack.push(asts.get(root).unwrap());
+
+    let mut warnings = Vec::new();
+
+    while let Some(ast) = stack.pop() {
+      for item in &ast.items {
+        match item {
+          Item::Alias(alias) => {
+            self.analyze_alias(alias)?;
+            self.aliases.insert(alias.clone());
+          }
+          Item::Assignment(assignment) => {
+            self.analyze_assignment(assignment)?;
+            self.assignments.insert(assignment.clone());
+          }
+          Item::Comment(_) => (),
+          Item::Recipe(recipe) => {
+            if recipe.enabled() {
+              Self::analyze_recipe(recipe)?;
+              recipes.push(recipe);
+            }
+          }
+          Item::Set(set) => {
+            self.analyze_set(set)?;
+            self.sets.insert(set.clone());
+          }
+          Item::Include { absolute, .. } => {
+            stack.push(asts.get(absolute.as_ref().unwrap()).unwrap());
           }
         }
-        Item::Set(set) => {
-          self.analyze_set(set)?;
-          self.sets.insert(set.clone());
-        }
       }
+
+      warnings.extend(ast.warnings.iter().cloned());
     }
 
     let settings = Settings::from_setting_iter(self.sets.into_iter().map(|(_, set)| set.value));
@@ -66,10 +87,12 @@ impl<'src> Analyzer<'src> {
       aliases.insert(Self::resolve_alias(&recipes, alias)?);
     }
 
+    let root = paths.get(root).unwrap();
+
     Ok(Justfile {
-      warnings: ast.warnings.clone(),
-      first: recipes
+      default: recipes
         .values()
+        .filter(|recipe| recipe.name.path == root)
         .fold(None, |accumulator, next| match accumulator {
           None => Some(Rc::clone(next)),
           Some(previous) => Some(if previous.line_number() < next.line_number() {
@@ -80,8 +103,10 @@ impl<'src> Analyzer<'src> {
         }),
       aliases,
       assignments: self.assignments,
+      loaded,
       recipes,
       settings,
+      warnings,
     })
   }
 
@@ -150,7 +175,7 @@ impl<'src> Analyzer<'src> {
     }
 
     for attr in &alias.attributes {
-      if !VALID_ALIAS_ATTRIBUTES.contains(attr) {
+      if *attr != Attribute::Private {
         return Err(alias.name.token().error(AliasInvalidAttribute {
           alias: name,
           attr: *attr,
