@@ -3,12 +3,19 @@ use {
   clap::{App, AppSettings, Arg, ArgGroup, ArgMatches, ArgSettings},
 };
 
-// These three strings should be kept in sync:
-pub(crate) const CHOOSER_DEFAULT: &str = "fzf --multi --preview 'just --show {}'";
 pub(crate) const CHOOSER_ENVIRONMENT_KEY: &str = "JUST_CHOOSER";
-pub(crate) const CHOOSE_HELP: &str = "Select one or more recipes to run using a binary. If \
-                                      `--chooser` is not passed the chooser defaults to the value \
-                                      of $JUST_CHOOSER, falling back to `fzf`";
+
+pub(crate) const CHOOSE_HELP: &str = "Select one or more recipes to run using a binary chooser. \
+                                      If `--chooser` is not passed the chooser defaults to the \
+                                      value of $JUST_CHOOSER, falling back to `fzf`";
+
+pub(crate) fn chooser_default(justfile: &Path) -> OsString {
+  let mut chooser = OsString::new();
+  chooser.push("fzf --multi --preview 'just --unstable --color always --justfile \"");
+  chooser.push(justfile);
+  chooser.push("\" --show {}'");
+  chooser
+}
 
 #[derive(Debug, PartialEq)]
 #[allow(clippy::struct_excessive_bools)]
@@ -33,6 +40,7 @@ pub(crate) struct Config {
   pub(crate) unsorted: bool,
   pub(crate) unstable: bool,
   pub(crate) verbosity: Verbosity,
+  pub(crate) yes: bool,
 }
 
 mod cmd {
@@ -106,6 +114,7 @@ mod arg {
   pub(crate) const UNSTABLE: &str = "UNSTABLE";
   pub(crate) const VERBOSE: &str = "VERBOSE";
   pub(crate) const WORKING_DIRECTORY: &str = "WORKING-DIRECTORY";
+  pub(crate) const YES: &str = "YES";
 
   pub(crate) const COLOR_ALWAYS: &str = "always";
   pub(crate) const COLOR_AUTO: &str = "auto";
@@ -168,6 +177,7 @@ impl Config {
           .possible_values(arg::COMMAND_COLOR_VALUES)
           .help("Echo recipe lines in <COMMAND-COLOR>"),
       )
+      .arg(Arg::with_name(arg::YES).long("yes").help("Automatically confirm all recipes."))
       .arg(
         Arg::with_name(arg::DRY_RUN)
           .short("n")
@@ -622,14 +632,14 @@ impl Config {
 
     Ok(Self {
       check: matches.is_present(arg::CHECK),
+      color,
+      command_color,
+      dotenv_filename: matches.value_of(arg::DOTENV_FILENAME).map(str::to_owned),
+      dotenv_path: matches.value_of(arg::DOTENV_PATH).map(PathBuf::from),
       dry_run: matches.is_present(arg::DRY_RUN),
       dump_format: Self::dump_format_from_matches(matches)?,
       highlight: !matches.is_present(arg::NO_HIGHLIGHT),
-      shell: matches.value_of(arg::SHELL).map(str::to_owned),
-      load_dotenv: !matches.is_present(arg::NO_DOTENV),
-      shell_command: matches.is_present(arg::SHELL_COMMAND),
-      unsorted: matches.is_present(arg::UNSORTED),
-      unstable,
+      invocation_directory,
       list_heading: matches
         .value_of(arg::LIST_HEADING)
         .unwrap_or("Available recipes:\n")
@@ -638,15 +648,16 @@ impl Config {
         .value_of(arg::LIST_PREFIX)
         .unwrap_or("    ")
         .to_owned(),
-      color,
-      command_color,
-      invocation_directory,
+      load_dotenv: !matches.is_present(arg::NO_DOTENV),
       search_config,
+      shell: matches.value_of(arg::SHELL).map(str::to_owned),
       shell_args,
+      shell_command: matches.is_present(arg::SHELL_COMMAND),
       subcommand,
-      dotenv_filename: matches.value_of(arg::DOTENV_FILENAME).map(str::to_owned),
-      dotenv_path: matches.value_of(arg::DOTENV_PATH).map(PathBuf::from),
+      unsorted: matches.is_present(arg::UNSORTED),
+      unstable,
       verbosity,
+      yes: matches.is_present(arg::YES),
     })
   }
 
