@@ -88,9 +88,8 @@ pub(crate) enum Error<'src> {
     function: Name<'src>,
     message: String,
   },
-  IncludeMissingPath {
-    file: PathBuf,
-    line: usize,
+  GetConfirmation {
+    io_error: io::Error,
   },
   InitExists {
     justfile: PathBuf,
@@ -98,9 +97,6 @@ pub(crate) enum Error<'src> {
   Internal {
     message: String,
   },
-  InvalidDirective {
-    line: String,
-  },
   Io {
     recipe: &'src str,
     io_error: io::Error,
@@ -110,7 +106,11 @@ pub(crate) enum Error<'src> {
     io_error: io::Error,
   },
   NoChoosableRecipes,
+  NoDefaultRecipe,
   NoRecipes,
+  NotConfirmed {
+    recipe: &'src str,
+  },
   RegexCompile {
     source: regex::Error,
   },
@@ -329,10 +329,8 @@ impl<'src> ColorDisplay for Error<'src> {
         let function = function.lexeme();
         write!(f, "Call to function `{function}` failed: {message}")?;
       }
-      IncludeMissingPath { file: justfile, line } => {
-        let line = line.ordinal();
-        let justfile = justfile.display();
-        write!(f, "!include directive on line {line} of `{justfile}` has no argument")?;
+      GetConfirmation { io_error } => {
+        write!(f, "Failed to read confirmation from stdin: {io_error}")?;
       }
       InitExists { justfile } => {
         write!(f, "Justfile `{}` already exists", justfile.display())?;
@@ -341,9 +339,6 @@ impl<'src> ColorDisplay for Error<'src> {
         write!(f, "Internal runtime error, this may indicate a bug in just: {message} \
                    consider filing an issue: https://github.com/casey/just/issues/new")?;
       }
-      InvalidDirective { line } => {
-        write!(f, "Invalid directive: {line}")?;
-      }
       Io { recipe, io_error } => {
         match io_error.kind() {
           io::ErrorKind::NotFound => write!(f, "Recipe `{recipe}` could not be run because just could not find the shell: {io_error}"),
@@ -356,7 +351,11 @@ impl<'src> ColorDisplay for Error<'src> {
         write!(f, "Failed to read justfile at `{path}`: {io_error}")?;
       }
       NoChoosableRecipes => write!(f, "Justfile contains no choosable recipes.")?,
+      NoDefaultRecipe => write!(f, "Justfile contains no default recipe.")?,
       NoRecipes => write!(f, "Justfile contains no recipes.")?,
+      NotConfirmed { recipe } => {
+        write!(f, "Recipe `{recipe}` was not confirmed")?;
+      }
       RegexCompile { source } => write!(f, "{source}")?,
       Search { search_error } => Display::fmt(search_error, f)?,
       Shebang { recipe, command, argument, io_error} => {
