@@ -8,6 +8,10 @@ pub(crate) enum Item<'src> {
   Comment(&'src str),
   Recipe(UnresolvedRecipe<'src>),
   Set(Set<'src>),
+  Include {
+    relative: &'src str,
+    absolute: Option<PathBuf>,
+  },
 }
 
 impl<'src> Display for Item<'src> {
@@ -18,6 +22,7 @@ impl<'src> Display for Item<'src> {
       Item::Comment(comment) => write!(f, "{comment}"),
       Item::Recipe(recipe) => write!(f, "{}", recipe.color_display(Color::never())),
       Item::Set(set) => write!(f, "{set}"),
+      Item::Include { relative, .. } => write!(f, "!include {relative}"),
     }
   }
 }
