@@ -5,7 +5,9 @@ use super::*;
 pub(crate) enum Keyword {
   Alias,
   AllowDuplicateRecipes,
+  DotenvFilename,
   DotenvLoad,
+  DotenvPath,
   Else,
   Export,
   Fallback,
