@@ -350,6 +350,9 @@ impl<'tokens, 'src> Parser<'tokens, 'src> {
             }
           }
         }
+      } else if self.next_is(Bang) {
+        let directive = self.parse_directive()?;
+        items.push(directive);
       } else if self.accepted(At)? {
         let doc = pop_doc_comment(&mut items, eol_since_last_comment);
         items.push(Item::Recipe(self.parse_recipe(
@@ -775,6 +778,24 @@ impl<'tokens, 'src> Parser<'tokens, 'src> {
     Ok(value)
   }
 
+  fn parse_directive(&mut self) -> CompileResult<'src, Item<'src>> {
+    self.presume(Bang)?;
+    let name = self.expect(Identifier)?;
+    match name.lexeme() {
+      "include" => {
+        if let Some(include_line) = self.accept(Text)? {
+          Ok(Item::Include {
+            relative: include_line.lexeme().trim(),
+            absolute: None,
+          })
+        } else {
+          Err(self.error(CompileErrorKind::IncludeMissingPath)?)
+        }
+      }
+      directive => Err(name.error(CompileErrorKind::UnknownDirective { directive })),
+    }
+  }
+
   /// Parse a setting
   fn parse_set(&mut self) -> CompileResult<'src, Set<'src>> {
     self.presume_keyword(Keyword::Set)?;
@@ -906,7 +927,7 @@ mod tests {
 
   fn test(text: &str, want: Tree) {
     let unindented = unindent(text);
-    let tokens = Lexer::lex(&unindented).expect("lexing failed");
+    let tokens = Lexer::test_lex(&unindented).expect("lexing failed");
     let justfile = Parser::parse(&tokens).expect("parsing failed");
     let have = justfile.tree();
     if have != want {
@@ -943,7 +964,7 @@ mod tests {
     length: usize,
     kind: CompileErrorKind,
   ) {
-    let tokens = Lexer::lex(src).expect("Lexing failed in parse test...");
+    let tokens = Lexer::test_lex(src).expect("Lexing failed in parse test...");
 
     match Parser::parse(&tokens) {
       Ok(_) => panic!("Parsing unexpectedly succeeded"),
@@ -956,6 +977,7 @@ mod tests {
             line,
             column,
             length,
+            path: "justfile".as_ref(),
           },
           kind: Box::new(kind),
         };
@@ -1020,11 +1042,11 @@ mod tests {
 
   test! {
       name: recipe_named_alias,
-      text: r#"
+      text: r"
       [private]
       alias:
         echo 'echoing alias'
-          "#,
+          ",
     tree: (justfile
       (recipe alias (body ("echo 'echoing alias'")))
     ),
@@ -1154,13 +1176,13 @@ mod tests {
 
   test! {
     name: recipe_plus_variadic,
-    text: r#"foo +bar:"#,
+    text: r"foo +bar:",
     tree: (justfile (recipe foo (params +(bar)))),
   }
 
   test! {
     name: recipe_star_variadic,
-    text: r#"foo *bar:"#,
+    text: r"foo *bar:",
     tree: (justfile (recipe foo (params *(bar)))),
   }
 
@@ -1172,13 +1194,13 @@ mod tests {
 
   test! {
     name: recipe_variadic_variable_default,
-    text: r#"foo +bar=baz:"#,
+    text: r"foo +bar=baz:",
     tree: (justfile (recipe foo (params +(bar baz)))),
   }
 
   test! {
     name: recipe_variadic_addition_group_default,
-    text: r#"foo +bar=(baz + bob):"#,
+    text: r"foo +bar=(baz + bob):",
     tree: (justfile (recipe foo (params +(bar ((+ baz bob)))))),
   }
 
@@ -1440,9 +1462,9 @@ mod tests {
 
   test! {
     name: recipe_variadic_with_default_after_default,
-    text: r#"
+    text: r"
       f a=b +c=d:
-    "#,
+    ",
     tree: (justfile (recipe f (params (a b) +(c d)))),
   }
 
@@ -1958,6 +1980,12 @@ mod tests {
     tree: (justfile (assignment a (if b == c d (if b == c d e)))),
   }
 
+  test! {
+    name: include_directive,
+    text: "!include      some/file/path.txt     \n",
+    tree: (justfile (include "some/file/path.txt")),
+  }
+
   error! {
     name:   alias_syntax_multiple_rhs,
     input:  "alias foo := bar baz",
@@ -2048,7 +2076,7 @@ mod tests {
     column: 0,
     width:  1,
     kind: UnexpectedToken {
-      expected: vec![At, BracketL, Comment, Eof, Eol, Identifier],
+      expected: vec![At, Bang, BracketL, Comment, Eof, Eol, Identifier],
       found: BraceL,
     },
   }
@@ -2400,4 +2428,16 @@ mod tests {
       expected: 3..3,
     },
   }
+
+  error! {
+    name: unknown_directive,
+    input: "!inclood",
+    offset: 1,
+    line: 0,
+    column: 1,
+    width: 7,
+    kind: UnknownDirective {
+      directive: "inclood"
+    },
+  }
 }
