@@ -6,6 +6,7 @@ pub(crate) enum TokenKind {
   Asterisk,
   At,
   Backtick,
+  Bang,
   BangEquals,
   BraceL,
   BraceR,
@@ -48,6 +49,7 @@ impl Display for TokenKind {
         Asterisk => "'*'",
         At => "'@'",
         Backtick => "backtick",
+        Bang => "'!'",
         BangEquals => "'!='",
         BraceL => "'{'",
         BraceR => "'}'",
