@@ -20,7 +20,7 @@ pub(crate) use {
     fs,
     io::Write,
     iter,
-    path::{Path, PathBuf},
+    path::{Path, PathBuf, MAIN_SEPARATOR},
     process::{Command, Stdio},
     str,
   },
@@ -42,6 +42,7 @@ mod choose;
 mod command;
 mod completions;
 mod conditional;
+mod confirm;
 mod delimiters;
 mod dotenv;
 mod edit;
